"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.jsonToOpml = exports.opmlToJson = exports.toJson = void 0;
const fast_xml_parser_1 = __importDefault(require("fast-xml-parser"));
const atomToJson_1 = __importDefault(require("./atomToJson"));
const rssToJson_1 = __importDefault(require("./rssToJson"));
const json1upgrade_1 = __importDefault(require("./json1upgrade"));
const opmlJson_1 = __importDefault(require("./opmlJson"));
const html_entities_1 = require("html-entities");
const xmlParserOptions = {
    attributeNamePrefix: '',
    ignoreAttributes: false,
    parseNodeValue: true,
    parseAttributeValue: true,
    trimValues: true,
};
const toJson = (data) => {
    if (typeof data === 'object') {
        if (data.version === 'https://jsonfeed.org/version/1.1') {
            return data;
        }
        else if (data.version === 'https://jsonfeed.org/version/1') {
            return json1upgrade_1.default(data);
        }
        throw new Error('Feed validation failure');
    }
    const validateRss = fast_xml_parser_1.default.validate(data);
    if (validateRss === true) {
        const jsonFeed = fast_xml_parser_1.default.parse(html_entities_1.decode(data), xmlParserOptions);
        if (jsonFeed.rss && jsonFeed.rss.channel) {
            return rssToJson_1.default(jsonFeed.rss.channel);
        }
        else if (jsonFeed.feed) {
            return atomToJson_1.default(jsonFeed.feed);
        }
        throw new Error('Unknown feed type');
    }
    throw new Error(validateRss && validateRss.err && validateRss.err.msg ? validateRss.err.msg : 'Feed validation failure');
};
exports.toJson = toJson;
const opmlToJson = (data) => {
    data = data.trim();
    const validateOpml = fast_xml_parser_1.default.validate(data);
    if (validateOpml === true) {
        const opmlFeed = fast_xml_parser_1.default.parse(html_entities_1.decode(data), xmlParserOptions);
        if (opmlFeed.opml && opmlFeed.opml.body && opmlFeed.opml.body.outline) {
            return opmlJson_1.default(opmlFeed.opml);
        }
        throw new Error('Unknown opml type');
    }
    throw new Error(validateOpml && validateOpml.err && validateOpml.err.msg ? validateOpml.err.msg : 'Opml validation failure');
};
exports.opmlToJson = opmlToJson;
const jsonToOpml = (data) => {
    const j2xParser = new fast_xml_parser_1.default.j2xParser({
        format: true,
        tagValueProcessor: (val) => html_entities_1.encode(val.toString()),
        attrValueProcessor: (val) => html_entities_1.encode(val),
    });
    return j2xParser.parse({ opml: data });
};
exports.jsonToOpml = jsonToOpml;
