"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lite_1 = __importDefault(require("mime/lite"));
const utils_1 = require("./utils");
const getAttachments = (item) => {
    const attachments = [];
    for (const a of item) {
        const mediaContent = {
            url: a.url,
            mime_type: a.type ? a.type : lite_1.default.getType('a.url') || 'application/octet-stream',
        };
        if (a.duration) {
            mediaContent.duration_in_seconds = a.duration;
        }
        if (a.fileSize) {
            mediaContent.size_in_bytes = a.fileSize;
        }
        attachments.push(mediaContent);
    }
    return attachments;
};
const rssToJson = (rss) => {
    if (!Array.isArray(rss.item)) {
        rss.item = [rss.item];
    }
    const rssFeed = {
        version: 'https://jsonfeed.org/version/1.1',
        title: utils_1.getStringFromAttr(rss.title),
        feed_url: rss.link,
        description: rss.description,
        items: rss.item.map((item) => {
            const rssItem = {
                title: utils_1.getStringFromAttr(item.title),
                url: item.link,
                id: item.guid ? utils_1.getStringFromAttr(item.guid) : item.link ? item.link : item.title,
            };
            if (item.pubDate) {
                rssItem.date_published = item.pubDate;
            }
            if (item.description) {
                rssItem.summary = utils_1.getStringFromAttr(item.description);
            }
            if (item['content:encoded']) {
                rssItem.content_html = utils_1.getStringFromAttr(item['content:encoded']);
            }
            if (item['dc:creator']) {
                if (!Array.isArray(item['dc:creator'])) {
                    item['dc:creator'] = [item['dc:creator']];
                }
                rssItem.authors = item['dc:creator'].map((name) => ({ name }));
            }
            if (item.category) {
                rssItem.tags = Array.isArray(item.category) ? item.category : [item.category];
            }
            if (item.enclosure) {
                rssItem.attachments = [
                    {
                        url: item.enclosure.url,
                        size_in_bytes: item.enclosure.length,
                        mime_type: item.enclosure.type,
                    },
                ];
            }
            else if (item['media:content']) {
                if (Array.isArray(item['media:content'])) {
                    rssItem.attachments = getAttachments(item['media:content']);
                }
                else {
                    if (item['media:content'].medium === 'image') {
                        rssItem.image = item['media:content'].url;
                    }
                    else {
                        rssItem.attachments = getAttachments([item['media:content']]);
                    }
                }
            }
            return rssItem;
        }),
    };
    if (rss.image) {
        rssFeed.icon = rss.image.url;
    }
    if (rss['sy:updatePeriod']) {
        rssFeed.updatePeriod = rss['sy:updatePeriod'];
    }
    if (rss['sy:updateFrequency']) {
        rssFeed.updateFrequency = rss['sy:updateFrequency'];
    }
    return rssFeed;
};
exports.default = rssToJson;
